#define _BSD_SOURCE 1
#define _POSIX_C_SOURCE 199309L

#if (defined(_WIN32) || defined(_WIN64))
	#define MyCORE_OS_WINDOWS_NT
#endif

// mycore
#include "third_party/modest/source/mycore/mythread.c"
#include "third_party/modest/source/mycore/thread_queue.c"
#include "third_party/modest/source/mycore/utils/mchar_async.c"
#include "third_party/modest/source/mycore/utils/mhash.c"
#include "third_party/modest/source/mycore/utils/mctree.c"
#include "third_party/modest/source/mycore/utils/mcobject_async.c"
#include "third_party/modest/source/mycore/utils/mcobject.c"
#include "third_party/modest/source/mycore/utils/mcsync.c"
#include "third_party/modest/source/mycore/utils/mcsimple.c"
#include "third_party/modest/source/mycore/utils/avl_tree.c"
#include "third_party/modest/source/mycore/myosi.c"
#include "third_party/modest/source/mycore/utils.c"
#include "third_party/modest/source/mycore/mystring.c"
#include "third_party/modest/source/mycore/incoming.c"

// myencoding
#include "third_party/modest/source/myencoding/encoding.c"
#include "third_party/modest/source/myencoding/detect.c"
#include "third_party/modest/source/myencoding/mystring.c"

// myunicode
#include "third_party/modest/source/myunicode/myosi.c"

// myport
#ifdef MyCORE_OS_WINDOWS_NT
	#include "third_party/modest/source/myport/windows_nt/mycore/io.c"
	#include "third_party/modest/source/myport/windows_nt/mycore/utils/mcsync.c"
	#include "third_party/modest/source/myport/windows_nt/mycore/memory.c"
	#include "third_party/modest/source/myport/windows_nt/mycore/thread.c"
	#include "third_party/modest/source/myport/windows_nt/mycore/perf.c"
#else
	#include "third_party/modest/source/myport/posix/mycore/io.c"
	#include "third_party/modest/source/myport/posix/mycore/utils/mcsync.c"
	#include "third_party/modest/source/myport/posix/mycore/memory.c"
	#include "third_party/modest/source/myport/posix/mycore/thread.c"
	#include "third_party/modest/source/myport/posix/mycore/perf.c"
#endif

// mycss
#include "third_party/modest/source/mycss/convert.c"
#include "third_party/modest/source/mycss/tokenizer.c"
#include "third_party/modest/source/mycss/check.c"
#include "third_party/modest/source/mycss/property/parser_image.c"
#include "third_party/modest/source/mycss/property/init.c"
#include "third_party/modest/source/mycss/property/parser_url.c"
#include "third_party/modest/source/mycss/property/parser_text_decoration.c"
#include "third_party/modest/source/mycss/property/serialization.c"
#include "third_party/modest/source/mycss/property/shared.c"
#include "third_party/modest/source/mycss/property/parser_background.c"
#include "third_party/modest/source/mycss/property/parser.c"
#include "third_party/modest/source/mycss/mycss.c"
#include "third_party/modest/source/mycss/tokenizer_global.c"
#include "third_party/modest/source/mycss/stack.c"
#include "third_party/modest/source/mycss/tokenizer_end.c"
#include "third_party/modest/source/mycss/an_plus_b.c"
#include "third_party/modest/source/mycss/namespace/init.c"
#include "third_party/modest/source/mycss/namespace/state.c"
#include "third_party/modest/source/mycss/namespace/serialization.c"
#include "third_party/modest/source/mycss/namespace/parser.c"
#include "third_party/modest/source/mycss/mystring.c"
#include "third_party/modest/source/mycss/stylesheet.c"
#include "third_party/modest/source/mycss/declaration/entry_destroy.c"
#include "third_party/modest/source/mycss/declaration/default.c"
#include "third_party/modest/source/mycss/declaration/init.c"
#include "third_party/modest/source/mycss/declaration/state.c"
#include "third_party/modest/source/mycss/declaration/serialization.c"
#include "third_party/modest/source/mycss/declaration/entry.c"
#include "third_party/modest/source/mycss/declaration/parser.c"
#include "third_party/modest/source/mycss/values/color.c"
#include "third_party/modest/source/mycss/values/units.c"
#include "third_party/modest/source/mycss/values/consume.c"
#include "third_party/modest/source/mycss/values/values.c"
#include "third_party/modest/source/mycss/values/serialization.c"
#include "third_party/modest/source/mycss/values/color_parser.c"
#include "third_party/modest/source/mycss/values/image.c"
#include "third_party/modest/source/mycss/values/destroy.c"
#include "third_party/modest/source/mycss/entry.c"
#include "third_party/modest/source/mycss/selectors/list.c"
#include "third_party/modest/source/mycss/selectors/value.c"
#include "third_party/modest/source/mycss/selectors/function_parser.c"
#include "third_party/modest/source/mycss/selectors/init.c"
#include "third_party/modest/source/mycss/selectors/pseudo.c"
#include "third_party/modest/source/mycss/selectors/state.c"
#include "third_party/modest/source/mycss/selectors/function.c"
#include "third_party/modest/source/mycss/selectors/serialization.c"
#include "third_party/modest/source/mycss/selectors/parser.c"
#include "third_party/modest/source/mycss/media/init.c"
#include "third_party/modest/source/mycss/media/state.c"
#include "third_party/modest/source/mycss/parser.c"

// myhtml
#include "third_party/modest/source/myhtml/tree.c"
#include "third_party/modest/source/myhtml/data_process.c"
#include "third_party/modest/source/myhtml/mynamespace.c"
#include "third_party/modest/source/myhtml/tokenizer.c"
#include "third_party/modest/source/myhtml/tokenizer_doctype.c"
#include "third_party/modest/source/myhtml/tokenizer_end.c"
#include "third_party/modest/source/myhtml/tokenizer_script.c"
#include "third_party/modest/source/myhtml/tag_init.c"
#include "third_party/modest/source/myhtml/rules.c"
#include "third_party/modest/source/myhtml/callback.c"
#include "third_party/modest/source/myhtml/serialization.c"
#include "third_party/modest/source/myhtml/myhtml.c"
#include "third_party/modest/source/myhtml/mystring.c"
#include "third_party/modest/source/myhtml/tag.c"
#include "third_party/modest/source/myhtml/token.c"
#include "third_party/modest/source/myhtml/stream.c"
#include "third_party/modest/source/myhtml/charef.c"
#include "third_party/modest/source/myhtml/parser.c"

// myurl
#include "third_party/modest/source/myurl/myosi.c"
#include "third_party/modest/source/myurl/punycode.c"
#include "third_party/modest/source/myurl/path.c"
#include "third_party/modest/source/myurl/scheme.c"
#include "third_party/modest/source/myurl/url.c"
#include "third_party/modest/source/myurl/utils.c"
#include "third_party/modest/source/myurl/serialization.c"
#include "third_party/modest/source/myurl/parser_end.c"
#include "third_party/modest/source/myurl/host.c"
#include "third_party/modest/source/myurl/parser.c"

// myfont
#include "third_party/modest/source/myfont/glyf.c"
#include "third_party/modest/source/myfont/myosi.c"
#include "third_party/modest/source/myfont/myfont.c"
#include "third_party/modest/source/myfont/os_2.c"
#include "third_party/modest/source/myfont/head.c"
#include "third_party/modest/source/myfont/hhea.c"
#include "third_party/modest/source/myfont/vmtx.c"
#include "third_party/modest/source/myfont/vhea.c"
#include "third_party/modest/source/myfont/name.c"
#include "third_party/modest/source/myfont/maxp.c"
#include "third_party/modest/source/myfont/pclt.c"
#include "third_party/modest/source/myfont/cmap.c"
#include "third_party/modest/source/myfont/hmtx.c"
#include "third_party/modest/source/myfont/loca.c"

// modest
#include "third_party/modest/source/modest/glue.c"
#include "third_party/modest/source/modest/finder/pseudo_class.c"
#include "third_party/modest/source/modest/finder/match.c"
#include "third_party/modest/source/modest/finder/thread.c"
#include "third_party/modest/source/modest/finder/finder.c"
#include "third_party/modest/source/modest/finder/type.c"
#include "third_party/modest/source/modest/render/tree.c"
#include "third_party/modest/source/modest/render/begin.c"
#include "third_party/modest/source/modest/render/binding.c"
#include "third_party/modest/source/modest/render/tree_node.c"
#include "third_party/modest/source/modest/layer/layer.c"
#include "third_party/modest/source/modest/node/raw_property.c"
#include "third_party/modest/source/modest/node/node.c"
#include "third_party/modest/source/modest/node/property.c"
#include "third_party/modest/source/modest/node/serialization.c"
#include "third_party/modest/source/modest/declaration.c"
#include "third_party/modest/source/modest/style/map.c"
#include "third_party/modest/source/modest/style/default.c"
#include "third_party/modest/source/modest/style/sheet.c"
#include "third_party/modest/source/modest/style/type.c"
#include "third_party/modest/source/modest/style/raw.c"
#include "third_party/modest/source/modest/modest.c"
